import opensim as osim
import os

model_fileName =    './out_scaled.osim'
markers_fileName =  './exp_markers.trc'
ExtLoads_fileName = './setup_extLoad.xml'
GRF_fileName =      './exp_grf.mot'


# time frames (only one step)
t0 = 0.245 # init time
t1 = 0.535 # end time # stride = 1.025 

########## Moco tracking simulation

modelProc = osim.ModelProcessor(model_fileName)
# modelProc.append( osim.ModOpAddExternalLoads(ExtLoads_fileName))
modelProc.append( osim.ModOpRemoveMuscles())
modelProc.append( osim.ModOpAddReserves(1000))

track = osim.MocoTrack()
track.setModel( modelProc)
track.set_initial_time(t0)
track.set_final_time(t1)
track.set_mesh_interval(0.01) # 100 Hz


########## marker tracking
track.setMarkersReferenceFromTRC(markers_fileName)
track.set_allow_unused_references(True)
markerWeights = osim.MocoWeightSet()
markerWeights.cloneAndAppend( osim.MocoWeight('R.Shoulder', 1))
markerWeights.cloneAndAppend( osim.MocoWeight('L.Shoulder', 1))
markerWeights.cloneAndAppend( osim.MocoWeight('R.Clavicle', 1))
markerWeights.cloneAndAppend( osim.MocoWeight('L.Clavicle', 1))
markerWeights.cloneAndAppend( osim.MocoWeight('R.ASIS',     4))
markerWeights.cloneAndAppend( osim.MocoWeight('L.ASIS',     4))
markerWeights.cloneAndAppend( osim.MocoWeight('S2',         4))
markerWeights.cloneAndAppend( osim.MocoWeight('R.TH1',      1))
markerWeights.cloneAndAppend( osim.MocoWeight('R.Knee',     2))
markerWeights.cloneAndAppend( osim.MocoWeight('L.Knee',     2))
markerWeights.cloneAndAppend( osim.MocoWeight('R.Ankle',    2))
markerWeights.cloneAndAppend( osim.MocoWeight('L.Ankle',    2))
markerWeights.cloneAndAppend( osim.MocoWeight('R.Heel',     3))
markerWeights.cloneAndAppend( osim.MocoWeight('L.Heel',     3))
markerWeights.cloneAndAppend( osim.MocoWeight('R.Toe',      3))
markerWeights.cloneAndAppend( osim.MocoWeight('L.Toe',      3))
markerWeights.cloneAndAppend( osim.MocoWeight('R.MT5',      3))
markerWeights.cloneAndAppend( osim.MocoWeight('L.MT5',      3))
track.set_markers_weight_set(markerWeights)

########## solve
track.printToXML('./tracking_study.xml')
solution = track.solve()
solution.write('./tracking_solution.sto')